﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Drawing;
using System.Reflection;

public class General
{
    #region Assembly Attribute

    public static string AssemblyTitle
    {
        get
        {
            object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyTitleAttribute), false);
            if (attributes.Length > 0)
            {
                AssemblyTitleAttribute titleAttribute = (AssemblyTitleAttribute)attributes[0];
                if (titleAttribute.Title != "")
                {
                    return titleAttribute.Title;
                }
            }
            return System.IO.Path.GetFileNameWithoutExtension(Assembly.GetExecutingAssembly().CodeBase);
        }
    }

    public static string AssemblyVersion
    {
        get
        {
            return Assembly.GetExecutingAssembly().GetName().Version.ToString();
        }
    }

    public static string AssemblyDescription
    {
        get
        {
            object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyDescriptionAttribute), false);
            if (attributes.Length == 0)
            {
                return "";
            }
            return ((AssemblyDescriptionAttribute)attributes[0]).Description;
        }
    }

    public static string AssemblyProduct
    {
        get
        {
            object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyProductAttribute), false);
            if (attributes.Length == 0)
            {
                return "";
            }
            return ((AssemblyProductAttribute)attributes[0]).Product;
        }
    }

    public static string AssemblyCopyright
    {
        get
        {
            object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCopyrightAttribute), false);
            if (attributes.Length == 0)
            {
                return "";
            }
            return ((AssemblyCopyrightAttribute)attributes[0]).Copyright;
        }
    }

    public static string AssemblyCompany
    {
        get
        {
            object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCompanyAttribute), false);
            if (attributes.Length == 0)
            {
                return "";
            }
            return ((AssemblyCompanyAttribute)attributes[0]).Company;
        }
    }
    #endregion

    public static CommonDll.Common g_Common = new CommonDll.Common();
    public static string g_ApplicationFolder = Application.StartupPath.Trim().Substring(0, Application.StartupPath.Trim().ToUpper().LastIndexOf("bin".ToUpper()));

    #region "ReadMe File"
    public static string g_ReadMeFilePath = g_ApplicationFolder + "ReadMe.txt";

    public static void InitializeReadMeFile()
    {
        if (!g_Common.GetFileExists(g_ReadMeFilePath))
        {
            g_Common.SetTextFileWriteLine(g_ReadMeFilePath, "• PC with USB serial port support");
            g_Common.SetTextFileWriteLine(g_ReadMeFilePath, "• USB Dongle: BT900-US");
            g_Common.SetTextFileWriteLine(g_ReadMeFilePath, "• Operation system: Windows XP, Windows7 or above");
            g_Common.SetTextFileWriteLine(g_ReadMeFilePath, "• Microsoft .NET Framework 4.5 or above");
        }
    }
    #endregion

    #region "Version File"
    public static string g_VersionFilePath = g_ApplicationFolder + "Version.txt";

    public static void InitializeVersionFile()
    {
        if (!g_Common.GetFileExists(g_VersionFilePath))
        {
            g_Common.SetTextFileWriteLine(g_VersionFilePath, "• Version 1.0.0.0");
            g_Common.SetTextFileWriteLine(g_VersionFilePath, "• New Release");

            g_Common.SetTextFileWriteLine(g_VersionFilePath, "• Version 2.0.0.0");
            g_Common.SetTextFileWriteLine(g_VersionFilePath, "• Update for New Product");
        }
    }
    #endregion

    #region "Update File"
    public static string g_UpdateFile = g_ApplicationFolder + "Update.txt";

    public static void InitializeUpdateFile()
    {
        if (!g_Common.GetFileExists(g_UpdateFile))
        {
            g_Common.SetTextFileWriteLine(g_UpdateFile, Application.ExecutablePath);
        }
    }
    #endregion

    #region "Config File"
    public static string g_ConfigIniFilePath = g_ApplicationFolder + "Config.ini";
    public static string g_Language = "English";

    public static void InitializeConfigFile()
    {
        if (!g_Common.GetFileExists(g_ConfigIniFilePath))
        {
            //g_Common.SetIniFileWrite("System", "Language", g_Language, g_ConfigIniFilePath);
            g_Common.SetIniFileWrite("System", "PortName", "COM1", g_ConfigIniFilePath);
            g_Common.SetIniFileWrite("System", "PortSettings", "115200,N,8,1", g_ConfigIniFilePath);
            g_Common.SetIniFileWrite("System", "PressureUnit", "psi", g_ConfigIniFilePath);
            g_Common.SetIniFileWrite("System", "TemperatureUnit", "°C", g_ConfigIniFilePath);
        }
        else
        {
            g_Language = g_Common.GetIniFileRead("System", "Language", g_ConfigIniFilePath);
        }
    }

    #endregion

    #region "Work Directory"
    public static string g_DataFolderPath = g_ApplicationFolder + "Data" + "\\";

    public static void InitializeWorkDirectory()
    {
        if (!g_Common.GetDirectoryExists(g_DataFolderPath))
        {
            g_Common.SetDirectoryCreate(g_DataFolderPath);
        }
    }
    #endregion

    #region "System Config"
    public static string g_FontFamily = "Microsoft Sans Serif";
    public static float g_FontSize = 8.25f;
    public static Font g_Font = new Font(g_FontFamily, g_FontSize, FontStyle.Regular, GraphicsUnit.Pixel, (byte)134);

    public static bool g_IsUserTerminate = false;
    public static bool g_IsChangeMeasureRate = false;
    public static bool g_IsChangeDeviceName = false;

    public static void InitializeSystem()
    {
        InitializeReadMeFile();
        InitializeVersionFile();
        //InitializeUpdateFile();
        InitializeConfigFile();
        InitializeWorkDirectory();
    }
    #endregion

}
